==> kodekloud-downloader-0.0.2.tar.gz: kodekloud-downloader-0.0.2/src/kodekloud_downloader/main.py <==
import logging
from pathlib import Path
from typing import Union

import markdownify
import requests
from bs4 import BeautifulSoup

from kodekloud_downloader.helpers import download_all_pdf, download_video, is_normal_content, normalize_name
from kodekloud_downloader.models import Topic

logger = logging.getLogger(__name__)


def download_course(url: str, cookie: str, quality: str, output_dir: Union[str, Path]) -> None:
    page = requests.get(url, headers={"Cookie": cookie})
    soup = BeautifulSoup(page.content, "html.parser")
    course_name = soup.find("h1", class_="course_title").text.strip()
    main_lesson_content = soup.find("div", class_="lessons_main__content")
    topics = main_lesson_content.find_all("div", class_="w-dyn-item")
    items = []
    for topic in topics:
        items.append(Topic.make(topic))
    for i, item in enumerate(items, start=1):
        for j, lesson in enumerate(item.lessons, start=1):
            file_path = Path(
                Path(output_dir)
                / "KodeKloud"
                / normalize_name(course_name)
                / f"{i} - {normalize_name(item.name)}"
                / f"{j} - {normalize_name(lesson.name)}"
            )
            if lesson.is_video:
                logger.info(f"Writing video file... {file_path}...")
                file_path.parent.mkdir(parents=True, exist_ok=True)
                download_video(url=lesson.url, output_path=file_path, cookie=cookie, quality=quality)
            else:
                page = requests.get(lesson.url, headers={"Cookie": cookie})
                soup = BeautifulSoup(page.content, "html.parser")
                content = soup.find("div", class_="learndash_content_wrap")
                # TODO: Fix this part. Most probably resources are not getting downloaded
                if content and is_normal_content(content):
                    logger.info(f"Writing resource file... {file_path}...")
                    file_path.parent.mkdir(parents=True, exist_ok=True)
                    file_path.with_suffix(".md").write_text(
                        markdownify.markdownify(content.prettify()), encoding="utf-8"
                    )
                    download_all_pdf(content=content, download_path=file_path.parent, cookie=cookie)

==> kodekloud-downloader-0.0.6.tar.gz: kodekloud-downloader-0.0.6/src/kodekloud_downloader/main.py <==
import logging
from pathlib import Path
from typing import Union

import markdownify
import requests
import yt_dlp_patch  # noqa
import yt_dlp
from bs4 import BeautifulSoup

from kodekloud_downloader.helpers import (
    download_all_pdf,
    download_video,
    is_normal_content,
    normalize_name,
)
from kodekloud_downloader.models import Topic

logger = logging.getLogger(__name__)


def download_course(
    url: str, cookie: str, quality: str, output_dir: Union[str, Path]
) -> None:
    page = requests.get(url)
    soup = BeautifulSoup(page.content, "html.parser")
    course_name = soup.find("h1", class_="course_title").text.strip()
    main_lesson_content = soup.find("div", class_="lessons_main__content")
    topics = main_lesson_content.find_all("div", class_="w-dyn-item")
    items = []
    for topic in topics:
        items.append(Topic.make(topic))
    for i, item in enumerate(items, start=1):
        for j, lesson in enumerate(item.lessons, start=1):
            file_path = Path(
                Path(output_dir)
                / "KodeKloud"
                / normalize_name(course_name)
                / f"{i} - {normalize_name(item.name)}"
                / f"{j} - {normalize_name(lesson.name)}"
            )
            if lesson.is_video:
                logger.info(f"Writing video file... {file_path}...")
                file_path.parent.mkdir(parents=True, exist_ok=True)
                logger.info(f"Parsing url: {lesson.url}")
                try:
                    download_video(
                        url=lesson.url,
                        output_path=file_path,
                        cookie=cookie,
                        quality=quality,
                    )
                except yt_dlp.utils.UnsupportedError as ex:
                    logger.error(
                        f"Could not download video in link {lesson.url}. "
                        "Please open link manually and verify that video exists!"
                    )
                except yt_dlp.utils.DownloadError as ex:
                    logger.error(
                        f"Access denied while downloading video or audio file from link {lesson.url}"
                    )
            else:
                page = requests.get(lesson.url)
                soup = BeautifulSoup(page.content, "html.parser")
                content = soup.find("div", class_="learndash_content_wrap")
                # TODO: Fix this part. Most probably resources are not getting downloaded
                if content and is_normal_content(content):
                    logger.info(f"Writing resource file... {file_path}...")
                    file_path.parent.mkdir(parents=True, exist_ok=True)
                    file_path.with_suffix(".md").write_text(
                        markdownify.markdownify(content.prettify()), encoding="utf-8"
                    )
                    download_all_pdf(
                        content=content, download_path=file_path.parent, cookie=cookie
                    )
